@ECHO OFF

REM -- Check environment
IF %PROCESSOR_ARCHITECTURE% NEQ AMD64 (
	ECHO ERROR: This script must be run from 64-bit command prompt
	PAUSE
	EXIT /B 1
)
NET SESSION > NUL
IF %ERRORLEVEL% NEQ 0 (
	ECHO ERROR: This script must be run from elevated command prompt
	PAUSE
	EXIT /B 1
)

ECHO Creating root CA certificate...
makecert -r -n "CN=Altairis Root CA - TEST" -pe -sv root.pvk -a sha256 -b 01/01/2010 -e 12/31/2020 -len 2048 -cy authority root.cer

ECHO Importing certificate to root store...
powershell Import-Certificate -FilePath root.cer -CertStoreLocation "cert:\LocalMachine\Root"

ECHO Createing server certificates...
makecert -iv root.pvk -ic root.cer -n "CN=www.example.com,CN=example.com" -pe -sv www.example.com.pvk -a sha256 -len 2048 -m 12 -sky exchange -eku 1.3.6.1.5.5.7.3.1 www.example.com.cer
makecert -iv root.pvk -ic root.cer -n "CN=www.contoso.com,CN=contoso.com" -pe -sv www.contoso.com.pvk -a sha256 -len 2048 -m 12 -sky exchange -eku 1.3.6.1.5.5.7.3.1 www.contoso.com.cer
makecert -iv root.pvk -ic root.cer -n "CN=www.northwind.com,CN=northwind.com" -pe -sv www.northwind.com.pvk -a sha256 -len 2048 -m 12 -sky exchange -eku 1.3.6.1.5.5.7.3.1 www.northwind.com.cer
makecert -iv root.pvk -ic root.cer -n "CN=*.example.com" -pe -sv _.example.com.pvk -a sha256 -len 2048 -m 12 -sky exchange -eku 1.3.6.1.5.5.7.3.1 _.example.com.cer

ECHO Creating centralized certificate store folder...
MKDIR C:\CentralCertStore

ECHO Processing all server certificates...
FOR %%I IN (*.com.cer) DO (
	ECHO %%I

	REM -- Export to PFX in CCS folder
	pvk2pfx -pvk %%~nI.pvk -spc %%~nI.cer -pfx C:\CentralCertStore\%%~nI.pfx

	REM -- Delete CER/PVK files
	DEL %%~nI.cer
	DEL %%~nI.pvk
)
